`paddles` is a pedagogical algorithms and data structures library that aims to
- be thoroughly tested and documented
- be easy to install, use and understand
- adhere to good Python coding practices.

To install the library, type `pip install paddles` at the command line,
preferably after activating a virtual environment.
Your default Python version must be 3.10 or later.

This is version 0.1 of the library. It is a work in progress.
It currently implements the Stack, Queue and Deque abstract data types (ADTs).

The code repository is at https://github.com/dsa-ou/paddles.
The formatted documentation is at https://dsa-ou.github.io/paddles.

## Licence

`paddles` is Copyright © 2024 by The Open University, UK.
The code is licensed under a [BSD 3-clause licence](https://github.com/dsa-ou/paddles/blob/main/LICENSE).
The documentation is licensed under a
[Creative Commons Attribution 4.0 International Licence](http://creativecommons.org/licenses/by/4.0).